@@ -14,7 +14,7 @@ if __name__ == "__main__":
     call_command("migrate")
     TestRunner = get_runner(settings)
     test_runner = TestRunner()
-    tests_to_run = ["audoma_api"]
+    tests_to_run = ["audoma_api", "audoma.tests", "audoma.tests.drf"]
     try:
         tests_to_run = [sys.argv[1]]
     except IndexError:
